@@ -15,12 +15,12 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-#
 """This module contains Databricks operators."""
+from __future__ import annotations
 
 import time
 from logging import Logger
-from typing import TYPE_CHECKING, Any, Dict, List, Optional, Sequence, Union
+from typing import TYPE_CHECKING, Any, Sequence
 
 from airflow.compat.functools import cached_property
 from airflow.exceptions import AirflowException
@@ -147,7 +147,7 @@ class DatabricksJobRunLink(BaseOperatorLink):
         operator,
         dttm=None,
         *,
-        ti_key: Optional["TaskInstanceKey"] = None,
+        ti_key: TaskInstanceKey | None = None,
     ) -> str:
         if ti_key is not None:
             run_page_url = XCom.get_value(key=XCOM_RUN_PAGE_URL_KEY, ti_key=ti_key)
@@ -193,28 +193,28 @@ class DatabricksSubmitRunOperator(BaseOperator):
     :param spark_jar_task: The main class and parameters for the JAR task. Note that
         the actual JAR is specified in the ``libraries``.
         *EITHER* ``spark_jar_task`` *OR* ``notebook_task`` *OR* ``spark_python_task``
-        *OR* ``spark_submit_task`` *OR* ``pipeline_task`` should be specified.
+        *OR* ``spark_submit_task`` *OR* ``pipeline_task`` *OR* ``dbt_task`` should be specified.
         This field will be templated.
 
         .. seealso::
             https://docs.databricks.com/dev-tools/api/2.0/jobs.html#jobssparkjartask
     :param notebook_task: The notebook path and parameters for the notebook task.
         *EITHER* ``spark_jar_task`` *OR* ``notebook_task`` *OR* ``spark_python_task``
-        *OR* ``spark_submit_task`` *OR* ``pipeline_task`` should be specified.
+        *OR* ``spark_submit_task`` *OR* ``pipeline_task`` *OR* ``dbt_task`` should be specified.
         This field will be templated.
 
         .. seealso::
             https://docs.databricks.com/dev-tools/api/2.0/jobs.html#jobsnotebooktask
     :param spark_python_task: The python file path and parameters to run the python file with.
         *EITHER* ``spark_jar_task`` *OR* ``notebook_task`` *OR* ``spark_python_task``
-        *OR* ``spark_submit_task`` *OR* ``pipeline_task`` should be specified.
+        *OR* ``spark_submit_task`` *OR* ``pipeline_task`` *OR* ``dbt_task`` should be specified.
         This field will be templated.
 
         .. seealso::
             https://docs.databricks.com/dev-tools/api/2.0/jobs.html#jobssparkpythontask
     :param spark_submit_task: Parameters needed to run a spark-submit command.
         *EITHER* ``spark_jar_task`` *OR* ``notebook_task`` *OR* ``spark_python_task``
-        *OR* ``spark_submit_task`` *OR* ``pipeline_task`` should be specified.
+        *OR* ``spark_submit_task`` *OR* ``pipeline_task`` *OR* ``dbt_task`` should be specified.
         This field will be templated.
 
         .. seealso::
@@ -222,11 +222,18 @@ class DatabricksSubmitRunOperator(BaseOperator):
     :param pipeline_task: Parameters needed to execute a Delta Live Tables pipeline task.
         The provided dictionary must contain at least ``pipeline_id`` field!
         *EITHER* ``spark_jar_task`` *OR* ``notebook_task`` *OR* ``spark_python_task``
-        *OR* ``spark_submit_task`` *OR* ``pipeline_task`` should be specified.
+        *OR* ``spark_submit_task`` *OR* ``pipeline_task`` *OR* ``dbt_task`` should be specified.
         This field will be templated.
 
         .. seealso::
             https://docs.databricks.com/dev-tools/api/2.0/jobs.html#jobspipelinetask
+    :param dbt_task: Parameters needed to execute a dbt task.
+        The provided dictionary must contain at least the ``commands`` field and the
+        ``git_source`` parameter also needs to be set.
+        *EITHER* ``spark_jar_task`` *OR* ``notebook_task`` *OR* ``spark_python_task``
+        *OR* ``spark_submit_task`` *OR* ``pipeline_task`` *OR* ``dbt_task`` should be specified.
+        This field will be templated.
+
     :param new_cluster: Specs for a new cluster on which this task will be run.
         *EITHER* ``new_cluster`` *OR* ``existing_cluster_id`` should be specified
         (except when ``pipeline_task`` is used).
@@ -288,28 +295,29 @@ class DatabricksSubmitRunOperator(BaseOperator):
     def __init__(
         self,
         *,
-        json: Optional[Any] = None,
-        tasks: Optional[List[object]] = None,
-        spark_jar_task: Optional[Dict[str, str]] = None,
-        notebook_task: Optional[Dict[str, str]] = None,
-        spark_python_task: Optional[Dict[str, Union[str, List[str]]]] = None,
-        spark_submit_task: Optional[Dict[str, List[str]]] = None,
-        pipeline_task: Optional[Dict[str, str]] = None,
-        new_cluster: Optional[Dict[str, object]] = None,
-        existing_cluster_id: Optional[str] = None,
-        libraries: Optional[List[Dict[str, str]]] = None,
-        run_name: Optional[str] = None,
-        timeout_seconds: Optional[int] = None,
+        json: Any | None = None,
+        tasks: list[object] | None = None,
+        spark_jar_task: dict[str, str] | None = None,
+        notebook_task: dict[str, str] | None = None,
+        spark_python_task: dict[str, str | list[str]] | None = None,
+        spark_submit_task: dict[str, list[str]] | None = None,
+        pipeline_task: dict[str, str] | None = None,
+        dbt_task: dict[str, str | list[str]] | None = None,
+        new_cluster: dict[str, object] | None = None,
+        existing_cluster_id: str | None = None,
+        libraries: list[dict[str, str]] | None = None,
+        run_name: str | None = None,
+        timeout_seconds: int | None = None,
         databricks_conn_id: str = 'databricks_default',
         polling_period_seconds: int = 30,
         databricks_retry_limit: int = 3,
         databricks_retry_delay: int = 1,
-        databricks_retry_args: Optional[Dict[Any, Any]] = None,
+        databricks_retry_args: dict[Any, Any] | None = None,
         do_xcom_push: bool = True,
-        idempotency_token: Optional[str] = None,
-        access_control_list: Optional[List[Dict[str, str]]] = None,
+        idempotency_token: str | None = None,
+        access_control_list: list[dict[str, str]] | None = None,
         wait_for_termination: bool = True,
-        git_source: Optional[Dict[str, str]] = None,
+        git_source: dict[str, str] | None = None,
         **kwargs,
     ) -> None:
         """Creates a new ``DatabricksSubmitRunOperator``."""
@@ -333,6 +341,8 @@ class DatabricksSubmitRunOperator(BaseOperator):
             self.json['spark_submit_task'] = spark_submit_task
         if pipeline_task is not None:
             self.json['pipeline_task'] = pipeline_task
+        if dbt_task is not None:
+            self.json['dbt_task'] = dbt_task
         if new_cluster is not None:
             self.json['new_cluster'] = new_cluster
         if existing_cluster_id is not None:
@@ -352,9 +362,12 @@ class DatabricksSubmitRunOperator(BaseOperator):
         if git_source is not None:
             self.json['git_source'] = git_source
 
+        if 'dbt_task' in self.json and 'git_source' not in self.json:
+            raise AirflowException('git_source is required for dbt_task')
+
         self.json = normalise_json_content(self.json)
         # This variable will be used in case our task gets killed.
-        self.run_id: Optional[int] = None
+        self.run_id: int | None = None
         self.do_xcom_push = do_xcom_push
 
     @cached_property
@@ -370,7 +383,7 @@ class DatabricksSubmitRunOperator(BaseOperator):
             caller=caller,
         )
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         self.run_id = self._hook.submit_run(self.json)
         _handle_databricks_operator_execution(self, self._hook, self.log, context)
 
@@ -392,7 +405,7 @@ class DatabricksSubmitRunDeferrableOperator(DatabricksSubmitRunOperator):
         self.run_id = hook.submit_run(self.json)
         _handle_deferrable_databricks_operator_execution(self, hook, self.log, context)
 
-    def execute_complete(self, context: Optional[dict], event: dict):
+    def execute_complete(self, context: dict | None, event: dict):
         _handle_deferrable_databricks_operator_completion(event, self.log)
 
 
@@ -560,20 +573,20 @@ class DatabricksRunNowOperator(BaseOperator):
     def __init__(
         self,
         *,
-        job_id: Optional[str] = None,
-        job_name: Optional[str] = None,
-        json: Optional[Any] = None,
-        notebook_params: Optional[Dict[str, str]] = None,
-        python_params: Optional[List[str]] = None,
-        jar_params: Optional[List[str]] = None,
-        spark_submit_params: Optional[List[str]] = None,
-        python_named_params: Optional[Dict[str, str]] = None,
-        idempotency_token: Optional[str] = None,
+        job_id: str | None = None,
+        job_name: str | None = None,
+        json: Any | None = None,
+        notebook_params: dict[str, str] | None = None,
+        python_params: list[str] | None = None,
+        jar_params: list[str] | None = None,
+        spark_submit_params: list[str] | None = None,
+        python_named_params: dict[str, str] | None = None,
+        idempotency_token: str | None = None,
         databricks_conn_id: str = 'databricks_default',
         polling_period_seconds: int = 30,
         databricks_retry_limit: int = 3,
         databricks_retry_delay: int = 1,
-        databricks_retry_args: Optional[Dict[Any, Any]] = None,
+        databricks_retry_args: dict[Any, Any] | None = None,
         do_xcom_push: bool = True,
         wait_for_termination: bool = True,
         **kwargs,
@@ -609,7 +622,7 @@ class DatabricksRunNowOperator(BaseOperator):
 
         self.json = normalise_json_content(self.json)
         # This variable will be used in case our task gets killed.
-        self.run_id: Optional[int] = None
+        self.run_id: int | None = None
         self.do_xcom_push = do_xcom_push
 
     @cached_property
@@ -625,7 +638,7 @@ class DatabricksRunNowOperator(BaseOperator):
             caller=caller,
         )
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = self._hook
         if 'job_name' in self.json:
             job_id = hook.find_job_id_by_name(self.json['job_name'])
@@ -654,5 +667,5 @@ class DatabricksRunNowDeferrableOperator(DatabricksRunNowOperator):
         self.run_id = hook.run_now(self.json)
         _handle_deferrable_databricks_operator_execution(self, hook, self.log, context)
 
-    def execute_complete(self, context: Optional[dict], event: dict):
+    def execute_complete(self, context: dict | None, event: dict):
         _handle_deferrable_databricks_operator_completion(event, self.log)
