@@ -15,12 +15,14 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-#
 """This module contains Databricks operators."""
+from __future__ import annotations
+
 import re
-from typing import TYPE_CHECKING, Optional, Sequence
+from typing import TYPE_CHECKING, Sequence
 from urllib.parse import urlparse
 
+from airflow.compat.functools import cached_property
 from airflow.exceptions import AirflowException
 from airflow.models import BaseOperator
 from airflow.providers.databricks.hooks.databricks import DatabricksHook
@@ -46,7 +48,7 @@ class DatabricksReposCreateOperator(BaseOperator):
     :param databricks_conn_id: Reference to the :ref:`Databricks connection <howto/connection:databricks>`.
         By default and in the common case this will be ``databricks_default``. To use
         token based authentication, provide the key ``token`` in the extra field for the
-        connection and create the key ``host`` and leave the ``host`` field empty.
+        connection and create the key ``host`` and leave the ``host`` field empty. (templated)
     :param databricks_retry_limit: Amount of times retry if the Databricks backend is
         unreachable. Its value must be greater than or equal to 1.
     :param databricks_retry_delay: Number of seconds to wait between retries (it
@@ -54,7 +56,7 @@ class DatabricksReposCreateOperator(BaseOperator):
     """
 
     # Used in airflow.models.BaseOperator
-    template_fields: Sequence[str] = ('repo_path', 'tag', 'branch')
+    template_fields: Sequence[str] = ('repo_path', 'tag', 'branch', 'databricks_conn_id')
 
     __git_providers__ = {
         "github.com": "gitHub",
@@ -69,10 +71,10 @@ class DatabricksReposCreateOperator(BaseOperator):
         self,
         *,
         git_url: str,
-        git_provider: Optional[str] = None,
-        branch: Optional[str] = None,
-        tag: Optional[str] = None,
-        repo_path: Optional[str] = None,
+        git_provider: str | None = None,
+        branch: str | None = None,
+        tag: str | None = None,
+        repo_path: str | None = None,
         ignore_existing_repo: bool = False,
         databricks_conn_id: str = 'databricks_default',
         databricks_retry_limit: int = 3,
@@ -90,7 +92,7 @@ class DatabricksReposCreateOperator(BaseOperator):
             self.git_provider = self.__detect_repo_provider__(git_url)
             if self.git_provider is None:
                 raise AirflowException(
-                    "git_provider isn't specified and couldn't be guessed" f" for URL {git_url}"
+                    f"git_provider isn't specified and couldn't be guessed for URL {git_url}"
                 )
         else:
             self.git_provider = git_provider
@@ -116,14 +118,16 @@ class DatabricksReposCreateOperator(BaseOperator):
             pass
         return provider
 
-    def _get_hook(self) -> DatabricksHook:
+    @cached_property
+    def _hook(self) -> DatabricksHook:
         return DatabricksHook(
             self.databricks_conn_id,
             retry_limit=self.databricks_retry_limit,
             retry_delay=self.databricks_retry_delay,
+            caller="DatabricksReposCreateOperator",
         )
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         """
         Creates a Databricks Repo
 
@@ -140,22 +144,21 @@ class DatabricksReposCreateOperator(BaseOperator):
                     f"repo_path should have form of /Repos/{{folder}}/{{repo-name}}, got '{self.repo_path}'"
                 )
             payload["path"] = self.repo_path
-        hook = self._get_hook()
         existing_repo_id = None
         if self.repo_path is not None:
-            existing_repo_id = hook.get_repo_by_path(self.repo_path)
+            existing_repo_id = self._hook.get_repo_by_path(self.repo_path)
             if existing_repo_id is not None and not self.ignore_existing_repo:
                 raise AirflowException(f"Repo with path '{self.repo_path}' already exists")
         if existing_repo_id is None:
-            result = hook.create_repo(payload)
+            result = self._hook.create_repo(payload)
             repo_id = result["id"]
         else:
             repo_id = existing_repo_id
         # update repo if necessary
         if self.branch is not None:
-            hook.update_repo(str(repo_id), {'branch': str(self.branch)})
+            self._hook.update_repo(str(repo_id), {'branch': str(self.branch)})
         elif self.tag is not None:
-            hook.update_repo(str(repo_id), {'tag': str(self.tag)})
+            self._hook.update_repo(str(repo_id), {'tag': str(self.tag)})
 
         return repo_id
 
@@ -173,7 +176,7 @@ class DatabricksReposUpdateOperator(BaseOperator):
     :param databricks_conn_id: Reference to the :ref:`Databricks connection <howto/connection:databricks>`.
         By default and in the common case this will be ``databricks_default``. To use
         token based authentication, provide the key ``token`` in the extra field for the
-        connection and create the key ``host`` and leave the ``host`` field empty.
+        connection and create the key ``host`` and leave the ``host`` field empty.  (templated)
     :param databricks_retry_limit: Amount of times retry if the Databricks backend is
         unreachable. Its value must be greater than or equal to 1.
     :param databricks_retry_delay: Number of seconds to wait between retries (it
@@ -181,15 +184,15 @@ class DatabricksReposUpdateOperator(BaseOperator):
     """
 
     # Used in airflow.models.BaseOperator
-    template_fields: Sequence[str] = ('repo_path', 'tag', 'branch')
+    template_fields: Sequence[str] = ('repo_path', 'tag', 'branch', 'databricks_conn_id')
 
     def __init__(
         self,
         *,
-        branch: Optional[str] = None,
-        tag: Optional[str] = None,
-        repo_id: Optional[str] = None,
-        repo_path: Optional[str] = None,
+        branch: str | None = None,
+        tag: str | None = None,
+        repo_id: str | None = None,
+        repo_path: str | None = None,
         databricks_conn_id: str = 'databricks_default',
         databricks_retry_limit: int = 3,
         databricks_retry_delay: int = 1,
@@ -213,17 +216,18 @@ class DatabricksReposUpdateOperator(BaseOperator):
         self.branch = branch
         self.tag = tag
 
-    def _get_hook(self) -> DatabricksHook:
+    @cached_property
+    def _hook(self) -> DatabricksHook:
         return DatabricksHook(
             self.databricks_conn_id,
             retry_limit=self.databricks_retry_limit,
             retry_delay=self.databricks_retry_delay,
+            caller="DatabricksReposUpdateOperator",
         )
 
-    def execute(self, context: 'Context'):
-        hook = self._get_hook()
+    def execute(self, context: Context):
         if self.repo_path is not None:
-            self.repo_id = hook.get_repo_by_path(self.repo_path)
+            self.repo_id = self._hook.get_repo_by_path(self.repo_path)
             if self.repo_id is None:
                 raise AirflowException(f"Can't find Repo ID for path '{self.repo_path}'")
         if self.branch is not None:
@@ -231,7 +235,7 @@ class DatabricksReposUpdateOperator(BaseOperator):
         else:
             payload = {'tag': str(self.tag)}
 
-        result = hook.update_repo(str(self.repo_id), payload)
+        result = self._hook.update_repo(str(self.repo_id), payload)
         return result['head_commit_id']
 
 
@@ -246,7 +250,7 @@ class DatabricksReposDeleteOperator(BaseOperator):
     :param databricks_conn_id: Reference to the :ref:`Databricks connection <howto/connection:databricks>`.
         By default and in the common case this will be ``databricks_default``. To use
         token based authentication, provide the key ``token`` in the extra field for the
-        connection and create the key ``host`` and leave the ``host`` field empty.
+        connection and create the key ``host`` and leave the ``host`` field empty. (templated)
     :param databricks_retry_limit: Amount of times retry if the Databricks backend is
         unreachable. Its value must be greater than or equal to 1.
     :param databricks_retry_delay: Number of seconds to wait between retries (it
@@ -254,13 +258,13 @@ class DatabricksReposDeleteOperator(BaseOperator):
     """
 
     # Used in airflow.models.BaseOperator
-    template_fields: Sequence[str] = ('repo_path',)
+    template_fields: Sequence[str] = ('repo_path', 'databricks_conn_id')
 
     def __init__(
         self,
         *,
-        repo_id: Optional[str] = None,
-        repo_path: Optional[str] = None,
+        repo_id: str | None = None,
+        repo_path: str | None = None,
         databricks_conn_id: str = 'databricks_default',
         databricks_retry_limit: int = 3,
         databricks_retry_delay: int = 1,
@@ -278,18 +282,19 @@ class DatabricksReposDeleteOperator(BaseOperator):
         self.repo_path = repo_path
         self.repo_id = repo_id
 
-    def _get_hook(self) -> DatabricksHook:
+    @cached_property
+    def _hook(self) -> DatabricksHook:
         return DatabricksHook(
             self.databricks_conn_id,
             retry_limit=self.databricks_retry_limit,
             retry_delay=self.databricks_retry_delay,
+            caller="DatabricksReposDeleteOperator",
         )
 
-    def execute(self, context: 'Context'):
-        hook = self._get_hook()
+    def execute(self, context: Context):
         if self.repo_path is not None:
-            self.repo_id = hook.get_repo_by_path(self.repo_path)
+            self.repo_id = self._hook.get_repo_by_path(self.repo_path)
             if self.repo_id is None:
                 raise AirflowException(f"Can't find Repo ID for path '{self.repo_path}'")
 
-        hook.delete_repo(str(self.repo_id))
+        self._hook.delete_repo(str(self.repo_id))
