@@ -15,17 +15,18 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-#
 """This module contains Databricks operators."""
+from __future__ import annotations
 
 import csv
 import json
-from typing import TYPE_CHECKING, Any, Dict, Iterable, List, Mapping, Optional, Sequence, Union
+from typing import TYPE_CHECKING, Any, Iterable, List, Mapping, Sequence, Tuple, cast
 
-from databricks.sql.common import ParamEscaper
+from databricks.sql.utils import ParamEscaper
 
 from airflow.exceptions import AirflowException
 from airflow.models import BaseOperator
+from airflow.providers.common.sql.hooks.sql import fetch_all_handler
 from airflow.providers.databricks.hooks.databricks_sql import DatabricksSqlHook
 
 if TYPE_CHECKING:
@@ -41,7 +42,7 @@ class DatabricksSqlOperator(BaseOperator):
         :ref:`howto/operator:DatabricksSqlOperator`
 
     :param databricks_conn_id: Reference to
-        :ref:`Databricks connection id<howto/connection:databricks>`
+        :ref:`Databricks connection id<howto/connection:databricks>` (templated)
     :param http_path: Optional string specifying HTTP path of Databricks SQL Endpoint or cluster.
         If not specified, it should be either specified in the Databricks connection's extra parameters,
         or ``sql_endpoint_name`` must be specified.
@@ -53,29 +54,46 @@ class DatabricksSqlOperator(BaseOperator):
     :param parameters: (optional) the parameters to render the SQL query with.
     :param session_configuration: An optional dictionary of Spark session parameters. Defaults to None.
         If not specified, it could be specified in the Databricks connection's extra parameters.
+    :param client_parameters: Additional parameters internal to Databricks SQL Connector parameters
+    :param http_headers: An optional list of (k, v) pairs that will be set as HTTP headers on every request.
+         (templated)
+    :param catalog: An optional initial catalog to use. Requires DBR version 9.0+ (templated)
+    :param schema: An optional initial schema to use. Requires DBR version 9.0+ (templated)
     :param output_path: optional string specifying the file to which write selected data. (templated)
     :param output_format: format of output data if ``output_path` is specified.
         Possible values are ``csv``, ``json``, ``jsonl``. Default is ``csv``.
     :param csv_params: parameters that will be passed to the ``csv.DictWriter`` class used to write CSV data.
+    :param do_xcom_push: If True, then the result of SQL executed will be pushed to an XCom.
     """
 
-    template_fields: Sequence[str] = ('sql', '_output_path')
+    template_fields: Sequence[str] = (
+        'sql',
+        '_output_path',
+        'schema',
+        'catalog',
+        'http_headers',
+        'databricks_conn_id',
+    )
     template_ext: Sequence[str] = ('.sql',)
     template_fields_renderers = {'sql': 'sql'}
 
     def __init__(
         self,
         *,
-        sql: Union[str, List[str]],
+        sql: str | Iterable[str],
         databricks_conn_id: str = DatabricksSqlHook.default_conn_name,
-        http_path: Optional[str] = None,
-        sql_endpoint_name: Optional[str] = None,
-        parameters: Optional[Union[Mapping, Iterable]] = None,
+        http_path: str | None = None,
+        sql_endpoint_name: str | None = None,
+        parameters: Iterable | Mapping | None = None,
         session_configuration=None,
+        http_headers: list[tuple[str, str]] | None = None,
+        catalog: str | None = None,
+        schema: str | None = None,
         do_xcom_push: bool = False,
-        output_path: Optional[str] = None,
+        output_path: str | None = None,
         output_format: str = 'csv',
-        csv_params: Optional[Dict[str, Any]] = None,
+        csv_params: dict[str, Any] | None = None,
+        client_parameters: dict[str, Any] | None = None,
         **kwargs,
     ) -> None:
         """Creates a new ``DatabricksSqlOperator``."""
@@ -90,6 +108,10 @@ class DatabricksSqlOperator(BaseOperator):
         self.parameters = parameters
         self.do_xcom_push = do_xcom_push
         self.session_config = session_configuration
+        self.http_headers = http_headers
+        self.catalog = catalog
+        self.schema = schema
+        self.client_parameters = client_parameters or {}
 
     def _get_hook(self) -> DatabricksSqlHook:
         return DatabricksSqlHook(
@@ -97,6 +119,11 @@ class DatabricksSqlOperator(BaseOperator):
             http_path=self._http_path,
             session_configuration=self.session_config,
             sql_endpoint_name=self._sql_endpoint_name,
+            http_headers=self.http_headers,
+            catalog=self.catalog,
+            schema=self.schema,
+            caller="DatabricksSqlOperator",
+            **self.client_parameters,
         )
 
     def _format_output(self, schema, results):
@@ -130,10 +157,11 @@ class DatabricksSqlOperator(BaseOperator):
         else:
             raise AirflowException(f"Unsupported output format: '{self._output_format}'")
 
-    def execute(self, context: 'Context') -> Any:
+    def execute(self, context: Context):
         self.log.info('Executing: %s', self.sql)
         hook = self._get_hook()
-        schema, results = hook.run(self.sql, parameters=self.parameters)
+        response = hook.run(self.sql, parameters=self.parameters, handler=fetch_all_handler)
+        schema, results = cast(List[Tuple[Any, Any]], response)[0]
         # self.log.info('Schema: %s', schema)
         # self.log.info('Results: %s', results)
         self._format_output(schema, results)
@@ -159,17 +187,24 @@ class DatabricksCopyIntoOperator(BaseOperator):
     :param file_format: Required file format. Supported formats are
         ``CSV``, ``JSON``, ``AVRO``, ``ORC``, ``PARQUET``, ``TEXT``, ``BINARYFILE``.
     :param databricks_conn_id: Reference to
-        :ref:`Databricks connection id<howto/connection:databricks>`
+        :ref:`Databricks connection id<howto/connection:databricks>` (templated)
     :param http_path: Optional string specifying HTTP path of Databricks SQL Endpoint or cluster.
         If not specified, it should be either specified in the Databricks connection's extra parameters,
         or ``sql_endpoint_name`` must be specified.
     :param sql_endpoint_name: Optional name of Databricks SQL Endpoint.
         If not specified, ``http_path`` must be provided as described above.
+    :param session_configuration: An optional dictionary of Spark session parameters. Defaults to None.
+        If not specified, it could be specified in the Databricks connection's extra parameters.
+    :param http_headers: An optional list of (k, v) pairs that will be set as HTTP headers on every request
+    :param catalog: An optional initial catalog to use. Requires DBR version 9.0+
+    :param schema: An optional initial schema to use. Requires DBR version 9.0+
+    :param client_parameters: Additional parameters internal to Databricks SQL Connector parameters
     :param files: optional list of files to import. Can't be specified together with ``pattern``. (templated)
     :param pattern: optional regex string to match file names to import.
         Can't be specified together with ``files``.
     :param expression_list: optional string that will be used in the ``SELECT`` expression.
-    :param credential: optional credential configuration for authentication against a specified location.
+    :param credential: optional credential configuration for authentication against a source location.
+    :param storage_credential: optional Unity Catalog storage credential for destination.
     :param encryption: optional encryption configuration for a specified location.
     :param format_options: optional dictionary with options specific for a given file format.
     :param force_copy: optional bool to control forcing of data import
@@ -183,6 +218,7 @@ class DatabricksCopyIntoOperator(BaseOperator):
         '_file_location',
         '_files',
         '_table_name',
+        'databricks_conn_id',
     )
 
     def __init__(
@@ -192,18 +228,23 @@ class DatabricksCopyIntoOperator(BaseOperator):
         file_location: str,
         file_format: str,
         databricks_conn_id: str = DatabricksSqlHook.default_conn_name,
-        http_path: Optional[str] = None,
-        sql_endpoint_name: Optional[str] = None,
+        http_path: str | None = None,
+        sql_endpoint_name: str | None = None,
         session_configuration=None,
-        files: Optional[List[str]] = None,
-        pattern: Optional[str] = None,
-        expression_list: Optional[str] = None,
-        credential: Optional[Dict[str, str]] = None,
-        encryption: Optional[Dict[str, str]] = None,
-        format_options: Optional[Dict[str, str]] = None,
-        force_copy: Optional[bool] = None,
-        copy_options: Optional[Dict[str, str]] = None,
-        validate: Optional[Union[bool, int]] = None,
+        http_headers: list[tuple[str, str]] | None = None,
+        client_parameters: dict[str, Any] | None = None,
+        catalog: str | None = None,
+        schema: str | None = None,
+        files: list[str] | None = None,
+        pattern: str | None = None,
+        expression_list: str | None = None,
+        credential: dict[str, str] | None = None,
+        storage_credential: str | None = None,
+        encryption: dict[str, str] | None = None,
+        format_options: dict[str, str] | None = None,
+        force_copy: bool | None = None,
+        copy_options: dict[str, str] | None = None,
+        validate: bool | int | None = None,
         **kwargs,
     ) -> None:
         """Creates a new ``DatabricksSqlOperator``."""
@@ -224,13 +265,18 @@ class DatabricksCopyIntoOperator(BaseOperator):
         self._sql_endpoint_name = sql_endpoint_name
         self.session_config = session_configuration
         self._table_name = table_name
+        self._catalog = catalog
+        self._schema = schema
         self._file_location = file_location
         self._expression_list = expression_list
         self._credential = credential
+        self._storage_credential = storage_credential
         self._encryption = encryption
         self._format_options = format_options
         self._copy_options = copy_options or {}
         self._validate = validate
+        self._http_headers = http_headers
+        self._client_parameters = client_parameters or {}
         if force_copy is not None:
             self._copy_options["force"] = 'true' if force_copy else 'false'
 
@@ -240,13 +286,18 @@ class DatabricksCopyIntoOperator(BaseOperator):
             http_path=self._http_path,
             session_configuration=self.session_config,
             sql_endpoint_name=self._sql_endpoint_name,
+            http_headers=self._http_headers,
+            catalog=self._catalog,
+            schema=self._schema,
+            caller="DatabricksCopyIntoOperator",
+            **self._client_parameters,
         )
 
     @staticmethod
     def _generate_options(
         name: str,
         escaper: ParamEscaper,
-        opts: Optional[Dict[str, str]] = None,
+        opts: dict[str, str] | None = None,
         escape_key: bool = True,
     ) -> str:
         formatted_opts = ""
@@ -280,6 +331,9 @@ class DatabricksCopyIntoOperator(BaseOperator):
             files_or_pattern = f"FILES = {escaper.escape_item(self._files)}\n"
         format_options = self._generate_options("FORMAT_OPTIONS", escaper, self._format_options) + "\n"
         copy_options = self._generate_options("COPY_OPTIONS", escaper, self._copy_options) + "\n"
+        storage_cred = ""
+        if self._storage_credential:
+            storage_cred = f" WITH (CREDENTIAL {self._storage_credential})"
         validation = ""
         if self._validate is not None:
             if isinstance(self._validate, bool):
@@ -292,16 +346,18 @@ class DatabricksCopyIntoOperator(BaseOperator):
                     )
                 validation = f"VALIDATE {self._validate} ROWS\n"
             else:
-                raise AirflowException("Incorrect data type for validate parameter: " + type(self._validate))
+                raise AirflowException(
+                    "Incorrect data type for validate parameter: " + str(type(self._validate))
+                )
         # TODO: think on how to make sure that table_name and expression_list aren't used for SQL injection
-        sql = f"""COPY INTO {self._table_name}
+        sql = f"""COPY INTO {self._table_name}{storage_cred}
 FROM {location}
 FILEFORMAT = {self._file_format}
 {validation}{files_or_pattern}{format_options}{copy_options}
 """
         return sql.strip()
 
-    def execute(self, context: 'Context') -> Any:
+    def execute(self, context: Context) -> Any:
         sql = self._create_sql_query()
         self.log.info('Executing: %s', sql)
         hook = self._get_hook()
